@@ -8,8 +8,11 @@ from .base import (
     KMeansPipeline,
     GaussBlurPipeline,
     HogTransformPipeline,
+    ResNet18EmbeddingPipeline,
     TfidfPipeline,
     ToLowerUrlRemovePipeline,
+    # MobileBertEmbeddingPipeline,
+    MiniLMEmbeddingPipeline,
 )
 
 from .models import get_model, ModelType, KEYWORD_REPLACEMENTS as MODEL_KEYWORD_REPLACEMENTS
@@ -24,8 +27,11 @@ __all__ = [
     "KMeansPipeline",
     "GaussBlurPipeline",
     "HogTransformPipeline",
+    "ResNet18EmbeddingPipeline",
     "TfidfPipeline",
     "ToLowerUrlRemovePipeline",
+    # "MobileBertEmbeddingPipeline",
+    "MiniLMEmbeddingPipeline",
     "get_model",
     "ModelType",
     "MODEL_KEYWORD_REPLACEMENTS",
